@@ -1,3 +1,21 @@
+"""This module provides the MkapiPlugin class.
+
+MkapiPlugin is a MkDocs plugin that generates Python API documentation.
+
+Configure your mkdocs.yml like below:
+
+    - plugins:
+        - search
+        - mkapi
+
+If you want to refer objects that don't exist in the `sys.path`, configure
+a `src_dirs` option:
+
+    - plugins:
+        - search
+        - mkapi
+            - src_dirs: [<path1>, <path2>, ...]
+"""
 import logging
 import os
 import re
@@ -9,35 +27,24 @@ from mkdocs.plugins import BasePlugin
 from mkdocs.structure.files import get_files
 
 import mkapi
-import mkapi.plugins.preprocess
 from mkapi.core.page import Page
 
 logger = logging.getLogger("mkdocs")
 
 
 class MkapiPlugin(BasePlugin):
-    config_scheme = (
-        ("src_dirs", config_options.Type(list, default=[])),
-    )
+    config_scheme = (("src_dirs", config_options.Type(list, default=[])),)
 
     def on_config(self, config):
+        """Inserts `src_dirs` to `sys.path`."""
         self.pages = {}
-        # api_dir = os.path.join(config["docs_dir"], self.config["api_dir"])
-        dirname = os.path.dirname(config["config_file_path"])
-        nav = config["nav"]
-        for page in nav:
-            for key, value in page.items():
-                if isinstance(value, str) and value.startswith("mkapi:"):
-                    root = value.split(":")[1]
-                    root = os.path.join(dirname, root)
-                    # contents = mkapi.plugins.preprocess.make_pages(root, api_dir)
-                    # page[key] = contents
         for src_dir in self.config["src_dirs"]:
             if src_dir not in sys.path:
                 sys.path.insert(0, src_dir)
         return config
 
     def on_files(self, files, config):
+        """Collects plugin css ans js and appends them to `files`."""
         root = os.path.join(os.path.dirname(mkapi.__file__), "theme")
         docs_dir = config["docs_dir"]
         config["docs_dir"] = root
@@ -71,12 +78,14 @@ class MkapiPlugin(BasePlugin):
         return files
 
     def on_page_markdown(self, markdown, page, config, files):
+        """Converts markdown to intermidiate version."""
         path = page.file.abs_src_path
         page = Page(markdown)
         self.pages[path] = page
         return page.markdown
 
     def on_page_content(self, html, page, config, files):
+        """Merges html and MkApi's node structure."""
         path = page.file.abs_src_path
         page = self.pages[path]
         return page.content(html)
